@@ -3,7 +3,6 @@
 
 #include <bluetooth-enums.h>
 #include "gnome-bluetooth-enum-types.h"
-#include "bluetooth-enums.h"
 #include <glib-object.h>
 
 /* enumerations from "bluetooth-enums.h" */
@@ -84,6 +83,7 @@ bluetooth_status_get_type (void)
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
+      { BLUETOOTH_STATUS_INVALID, "BLUETOOTH_STATUS_INVALID", "invalid" },
       { BLUETOOTH_STATUS_DISCONNECTED, "BLUETOOTH_STATUS_DISCONNECTED", "disconnected" },
       { BLUETOOTH_STATUS_CONNECTED, "BLUETOOTH_STATUS_CONNECTED", "connected" },
       { BLUETOOTH_STATUS_CONNECTING, "BLUETOOTH_STATUS_CONNECTING", "connecting" },
